@@ -36,10 +36,10 @@
 #include "tracker-keyfile-object.h"
 #include "tracker-language.h"
 #include "tracker-log.h"
-#include "tracker-media-art.h"
 #include "tracker-ontologies.h"
 #include "tracker-os-dependant.h"
 #include "tracker-sched.h"
+#include "tracker-storage.h"
 #include "tracker-type-utils.h"
 #include "tracker-utils.h"
 #include "tracker-locale.h"
