@@ -94,15 +94,9 @@ enum {
 	LAST_SIGNAL
 };
 
-typedef enum {
-	TRACKER_DECORATOR_ERROR_EMPTY,
-	TRACKER_DECORATOR_ERROR_PAUSED
-} TrackerDecoratorError;
-
 static guint signals[LAST_SIGNAL] = { 0 };
 static GInitableIface *parent_initable_iface;
 
-static GQuark tracker_decorator_error_quark         (void);
 static void   tracker_decorator_initable_iface_init (GInitableIface   *iface);
 
 G_DEFINE_QUARK (TrackerDecoratorError, tracker_decorator_error)
