@@ -351,6 +351,7 @@ file_notifier_add_node_foreach (GNode    *node,
 		tracker_file_system_set_property (priv->file_system, canonical,
 		                                  quark_property_filesystem_mtime,
 		                                  time_ptr);
+		g_object_unref (file_info);
 	}
 
 	return FALSE;
@@ -1118,6 +1119,7 @@ tracker_file_notifier_finalize (GObject *object)
 	g_object_unref (priv->monitor);
 	g_object_unref (priv->file_system);
 	g_object_unref (priv->cancellable);
+	g_object_unref (priv->connection);
 
 	g_list_free (priv->pending_index_roots);
 	g_timer_destroy (priv->timer);
